/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2003 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#include "history.h"
#include "settings.h"
#include <qsettings.h>

History::History(const QString &key, int size)/*{{{*/
{
	this->key = "/vyqchat/history/" + key;
	this->size = size;
}/*}}}*/

History::~History()/*{{{*/
{
	save();
}/*}}}*/

void History::append(const QString &txt)/*{{{*/
{
	QStringList::iterator it = l.find(txt);
	//
	// text not found on the list - append it
	if (it == l.end())
	{
		l.push_front(txt);
		//
		// remove last text item if history reached its max size
		if (l.count() > size)
			l.pop_back();
	}
	else //put the item to the front
	{
		l.push_front(txt);
		l.remove(it);
	}
}/*}}}*/

void History::save()/*{{{*/
{
	QSettings cfg;
	cfg.writeEntry(key, l);
}/*}}}*/

void History::load()/*{{{*/
{
	QSettings cfg;
	l = cfg.readListEntry(key);
}/*}}}*/

QString History::first()/*{{{*/
{
	return l.first(); 
}/*}}}*/

