/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2003 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#ifndef __VYPRESS_H
#define __VYPRESS_H

#include <qtextcodec.h>
#include <qhostaddress.h>

#define VY_PORT 8167
#define VY_MAXPACKETSIZE 1400

#define VY_UNKNOWN 254
#define	VY_WHOHERE '0'
#define	VY_IMHERE  '1'
#define	VY_SAY  '2'
#define	VY_NICKCHANGE '3'
#define	VY_JOIN   '4'
#define	VY_LEAVE  '5'
#define	VY_MESSAGE  '6'
#define	VY_MASSMESSAGE 'E'
#define	VY_MESSAGEACK  '7'
#define	VY_REMOTEEXEC  '8'
#define	VY_EXECACK  '9'
#define	VY_ME  'A'
#define	VY_NEWTOPIC  'B'
#define	VY_CURRTOPIC  'C'
#define	VY_CHANGESTAT  'D'
#define	VY_INFOREQ  'F'
#define	VY_INFOREQACK  'G'
#define	VY_BEEP  'H'
#define VY_BEEP_SIGNAL '0'
#define VY_BEEP_ACK '1'
#define	VY_SOUNDREQ  'I'
#define	VY_PRIVATE  'J'
#define	VY_PRIVATE_JOIN  '0'
#define	VY_PRIVATE_LEAVE  '1'
#define	VY_PRIVATE_SAY  '2'
#define	VY_PRIVATE_ME  '3'
#define	VY_HEREREQ  'L'
#define	VY_HEREACK  'K'
#define	VY_CHANGEACTIV  'M'
#define	VY_REQCHANNELS  'N'
#define	VY_REQCHANNELSACK  'O'

enum {
	STATUS_NORMAL = '0',
	STATUS_DND,
	STATUS_AWAY,
	STATUS_OFFLINE,
	STATUS_UNKNOWN, //for internal purposes
	
	RA_ACTIVE = '0',
	RA_NOTACTIVE,
	
	WIN_ACTIVE = '0',
	WIN_NOTACTIVE,
	
	GENDER_MALE = '0',
	GENDER_FEMALE
};

class VyPacket 
{
	private:
		char *ptrs[8];

		bool split(char *buffer, int num, int p_len);
		bool decode(char *p_data, int p_len, QTextCodec *txtcodec);
	public:
		enum VyPacketID {
		       VyWhoHere, VyImHere, VySay, VyNickChange, VyJoin, VyLeave, VyMessage, VyMassMessage,
		       VyMessageAck, VyRemoteExec, VyExeAck, VyMe, VyNewTopic, VyCurrTopic, VyChangeStat,
		       VyInfoReq, VyInfoReqAck, VyBeep, VyBeepSignal, VyBeepAck, VySoundReq, VyPrivateJoin,
		       VyPrivateLeave, VyPrivateSay, VyPrivateMe, VyHereReq, VyHereReqAck, VyChangeActive,
		       VyReqChannels, VyReqChannelsAck, VyUnknown
		     };

		VyPacketID ptype;
		QHostAddress source;
		QString channel;
		QString from;
		QString to;
		char status;
		char gender;
		char remoteactive;
		QString text;
		QString topic;
		QString answer;
		QString name;
		QString ip;
		QString computer;

		VyPacket(const QHostAddress &src, char *p_data, int p_len, QTextCodec *txtcodec);
		~VyPacket();
};

#endif

