/*
 * This file is a part of VyQChat.
 *
 * Copyright (C) 2002-2003 Pawel Stolowski <yogin@linux.bydg.org>
 *
 * VyQChat is free software; you can redestribute it and/or modify it
 * under terms of GNU General Public License by Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY. See GPL for more details.
 */

#ifndef __VYSOCKET_H
#define __VYSOCKET_H

#include <qtextcodec.h>
#include <qsocketdevice.h>
#include <qhostaddress.h>

class VyPacket;

class VyGetSocket: protected QSocketDevice
{
	private:
		QTextCodec *tc;
		char *buffer;
	public:
		VyGetSocket(QTextCodec *c);
		~VyGetSocket();
		VyPacket* readPacket();
		int socket() { return QSocketDevice::socket(); }
		bool isValid() { return QSocketDevice::isValid(); }
};

class VySendSocket: public QSocketDevice
{
	private:
		char *pdata;
		QTextCodec *tc;
		int plen;
		QHostAddress broadcast;
		void send(const QHostAddress &addr, const char *format, ...);
	public:
		VySendSocket(const QString &addr, QTextCodec *c);
		~VySendSocket();
		void vy_say(const QString &channel, const QString &nick, const QString &text);
		void vy_me(const QString &channel, const QString &nick, const QString &text);
		void vy_whohere(const QString &updater);
		void vy_imhere(const QString &updater, const QString &responder, char status, char gender);
		void vy_beep(const QHostAddress &addr, const QString& to, const QString& from);
		void vy_beepack(const QHostAddress &addr, const QString& to, const QString& from, char gender);
		void vy_join(const QString&, const QString&, char, char);
		void vy_leave(const QString &who, const QString &channel, char gender);
		void vy_private_join(const QHostAddress &addr, const QString &from, const QString &to, char gender);
		void vy_private_leave(const QHostAddress &addr, const QString &from, const QString &to, char gender);
		void vy_private_say(const QHostAddress &addr, const QString &from, const QString &to, const QString &text);
		void vy_private_me(const QHostAddress &addr, const QString &from, const QString &to, const QString &text);
		void vy_message(const QHostAddress &addr, const QString &from, const QString &to, const QString &text);
		void vy_massmessage(const QHostAddress &addr, const QString &from, const QString &to, const QString &text);
		void vy_messageack(const QHostAddress &addr, char status, const QString &from, const QString &to, char gender, const QString &answer);
		void vy_herereq(const QString &from, const QString &channel);
		void vy_hereack(const QHostAddress &addr, const QString &to, const QString &channel, const QString &from, char ra);
		void vy_inforeq(const QHostAddress &addr, const QString &to, const QString &from);
		void vy_inforeqack(const QHostAddress &addr, const QString &to, const QString &from, const QString &comp, const QString &name, const QString &ip, const QString &channels, const QString &answer);
		void vy_nickchange(const QString &from, const QString &to, char gender);
		void vy_changestatus(const QString &who, char status, char gender, const QString &answer);
		void vy_currenttopic(const QHostAddress &addr, const QString &to, const QString &channel, const QString &topic);
		void vy_newtopic(const QString &channel, const QString &topic, const QString &who);
};

#endif

